==> x21143641PythonLib-0.1.tar.gz: x21143641PythonLib-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'x21143641PythonLib',         # How you named your package folder (MyLib)
  packages = ['x21143641PythonLib'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Library to calculate the total amount',   # Give a short description about your library
  author = 'x21143641',                   # Type in your name
  author_email = 'x21143641@student.ncirl.ie',      # Type in your E-Mail
  url = 'https://github.com/praveergupta1/x21143641PythonLib',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/praveergupta1/x21143641PythonLib/archive/refs/tags/v_01.tar.gz',    # I explain this later on
  keywords = ['AMOUNT'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> x21143641PythonLib-0.1.1.tar.gz: x21143641PythonLib-0.1.1/setup.py <==
from distutils.core import setup
setup(
  name = 'x21143641PythonLib',         # How you named your package folder (MyLib)
  packages = ['x21143641PythonLib'],   # Chose the same as "name"
  version = '0.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Library to calculate the total amount',   # Give a short description about your library
  author = 'x21143641',                   # Type in your name
  author_email = 'x21143641@student.ncirl.ie',      # Type in your E-Mail
  url = 'https://github.com/praveergupta1/x21143641PythonLib',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/praveergupta1/x21143641PythonLib/archive/refs/tags/v_01.1.tar.gz',    # I explain this later on
  keywords = ['AMOUNT'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
